SET TERM ^ ;
EXECUTE BLOCK AS BEGIN
IF (NOT EXISTS(SELECT RDB$FIELD_NAME FROM RDB$RELATION_FIELDS WHERE RDB$RELATION_NAME = 'RELNA' AND RDB$FIELD_NAME = 'SHORT_TITLE')) THEN 
EXECUTE STATEMENT 'ALTER TABLE RELNA ADD SHORT_TITLE VARCHAR(30) DEFAULT NULL;';
END^
SET TERM ; ^



SET TERM ^ ;
EXECUTE BLOCK AS BEGIN
IF (NOT EXISTS(SELECT RDB$INDEX_NAME FROM RDB$INDICES WHERE RDB$INDEX_NAME = 'RELNA_SHORT_TITLE')) THEN 
EXECUTE STATEMENT 'CREATE INDEX RELNA_SHORT_TITLE ON RELNA (SHORT_TITLE);';
END^
SET TERM ; ^




SET TERM ^ ;

RECREATE PROCEDURE P_DOCUMENT_INFO_GET (
 PARAMIDNA        INTEGER)
RETURNS (
 IDNA             INTEGER,
 TITLE            VARCHAR(1024),
 IDLANG           INTEGER,
 IDICON           INTEGER,
 PUBLISH_DATE     DATE,
 INFORCE_DATE     DATE,
 REPEAL_DATE      DATE,
 OUTFORCE_DATE    DATE,
 ABRIV            VARCHAR(200),
 CELEX            VARCHAR(200),
 SHORT_TITLE      VARCHAR(30),
 ECLI             VARCHAR(48),
 DATE_LAST_CHANGE DATE,
 DATE_IMPORT      DATE,
 CHECKSUM         VARCHAR(64),
 PARTITION        INTEGER)
AS 
begin
          FOR
            SELECT IDNA, TITLE, IDLANG, IDICON, PUBLISH_DATE, INFORCE_DATE, REPEAL_DATE, OUTFORCE_DATE, ABRIV, CELEX, SHORT_TITLE, ECLI, DATE_LAST_CHANGE, DATE_IMPORT, CHECKSUM
            FROM RELNA
            WHERE IDNA=:PARAMIDNA
            INTO  :IDNA, :TITLE, :IDLANG, :IDICON, :PUBLISH_DATE, :INFORCE_DATE, :REPEAL_DATE, :OUTFORCE_DATE, :ABRIV, :CELEX, :SHORT_TITLE, :ECLI, :DATE_LAST_CHANGE, :DATE_IMPORT, :CHECKSUM
          DO
          BEGIN
          
            SELECT FIRST 1 PARTITION
            FROM RELSTR INNER JOIN EDITIONS ON RELSTR.IDEDITION=EDITIONS.IDEDITION
            WHERE IDNA=:PARAMIDNA
            PLAN JOIN (RELSTR INDEX (RELSTR_IDNA), EDITIONS INDEX (PK_EDITIONS))
            INTO  :PARTITION;
            
            SUSPEND;
          END
end^

SET TERM ; ^




SET TERM ^ ;

RECREATE PROCEDURE P_DOCUMENT_CREATE_EDIT (
 IDUSER        VARCHAR(50),
 DOCUMENT_DATA BLOB SUB_TYPE BINARY,
 DOCUMENT_INFO BLOB SUB_TYPE BINARY)
RETURNS (
 IDNA          INTEGER,
 RET_VAL       INTEGER)
AS 
DECLARE VARIABLE L_IDNA     INTEGER;
DECLARE VARIABLE L_IDUSER     VARCHAR(50);
DECLARE VARIABLE L_IS_LOCKED     SMALLINT;
begin
    L_IDNA = NULL;
    L_IDUSER = NULL;
    L_IS_LOCKED = NULL;

    INSERT INTO RELNA(TITLE, IDLANG, IDICON, PUBLISH_DATE, INFORCE_DATE, REPEAL_DATE, OUTFORCE_DATE, ABRIV, CELEX, DATE_LAST_CHANGE, DATE_IMPORT) 
    VALUES ('NEW DOCUMENT', 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP)
    RETURNING IDNA INTO :L_IDNA;

    IF (:L_IDNA IS NOT NULL) THEN
        BEGIN
            INSERT INTO TEMP_DOCUMENTS (IDNA,DOCUMENT_DATA,DOCUMENT_INFO,FIRST_LOAD,LAST_ACTION,USAGE_HISTORY,IDUSER,IS_LOCKED)
            SELECT IDNA, :DOCUMENT_DATA AS DOCUMENT_DATA, :DOCUMENT_INFO AS DOCUMENT_INFO, CAST('NOW' AS TIMESTAMP) AS FIRST_LOAD, CAST('NOW' AS TIMESTAMP) AS LAST_ACTION, :IDUSER || ',' AS USAGE_HISTORY, :IDUSER AS IDUSER, 0 AS IS_LOCKED
            FROM RELNA
            WHERE IDNA = :L_IDNA AND NOT EXISTS (SELECT * FROM TEMP_DOCUMENTS WHERE IDNA = :L_IDNA);

            IDNA = :L_IDNA;
        END
    ELSE
        BEGIN
            IDNA = 0;
            RET_VAL = 1;

            SUSPEND;
            EXIT;
        END

    L_IDNA = NULL;
    SELECT IDNA, DOCUMENT_DATA, DOCUMENT_INFO, IDUSER, IS_LOCKED
    FROM TEMP_DOCUMENTS
    WHERE IDNA=:IDNA
    INTO  :L_IDNA, :DOCUMENT_DATA, :DOCUMENT_INFO, :L_IDUSER, :L_IS_LOCKED;

    IF (:L_IDNA IS NULL) THEN
        BEGIN
            IDNA = 0;
            RET_VAL = 1;

            SUSPEND;
            EXIT;
        END

    RET_VAL = 0;
    SUSPEND;
end^

SET TERM ; ^
